# Models

## Overview

PreFab accommodates unique _predictor_ and _corrector_ models for each photonic foundry, regularly updated based on recent fabrication data.

| Foundry | Process | Latest Version    | Latest Dataset   | Model Name  | Model Tag |
| ------- | ------- | ----------------- | ---------------- | ----------- | --------- |
| ANT     | NanoSOI | ANF0 (Jan 1 2024) | d8 (Jan 1 2024)  | ANT_NanoSOI | ANF0-d8   |
| ANT     | NanoSOI | ANF1 (May 6 2024) | d8 (Jan 1 2024)  | ANT_NanoSOI | ANF1-d8   |
| ANT     | NanoSOI | ANF1 (May 6 2024) | d9 (Feb 6 2024)  | ANT_NanoSOI | ANF1-d9   |
| ANT     | NanoSOI | ANF1 (May 6 2024) | d10 (Jun 8 2024) | ANT_NanoSOI | ANF1-d10  |
| ANT     | SiN     | ANF1 (May 6 2024) | d1 (Jan 31 2024) | ANT_SiN     | ANF1-d1   |
| Generic | DUV-SOI | ANF1 (May 6 2024) | d0 (Jul 30 2024) | generic_DUV_SOI | ANF1-d0 |

New models and foundries are to be regularly added. Usage may change. For additional foundry and process models, feel free to contact us.
